# XIOS xml files
## Where are the nemo namelist (templates)
XIOS xml files are found in nemo's CONFIG folder e.g.
foci-default/nemo-3.6/CONFIG/ORCA05_LIM2_KCM_AOW/EXP00
to be consistent with the general NEMO handling of configurations
and namelists.
The xml files are kept for now until the OpenIFS setup has finished
Sebastian Wahl 2020-04-27
